vfbLib.parsers.base.OpenTypeKerningClassFlagsParser
===================================================

.. currentmodule:: vfbLib.parsers.base

.. autoclass:: OpenTypeKerningClassFlagsParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~OpenTypeKerningClassFlagsParser.__init__
      ~OpenTypeKerningClassFlagsParser.parse
      ~OpenTypeKerningClassFlagsParser.parse_hex
      ~OpenTypeKerningClassFlagsParser.read_double
      ~OpenTypeKerningClassFlagsParser.read_doubles
      ~OpenTypeKerningClassFlagsParser.read_float
      ~OpenTypeKerningClassFlagsParser.read_floats
      ~OpenTypeKerningClassFlagsParser.read_int16
      ~OpenTypeKerningClassFlagsParser.read_int32
      ~OpenTypeKerningClassFlagsParser.read_int8
      ~OpenTypeKerningClassFlagsParser.read_str
      ~OpenTypeKerningClassFlagsParser.read_str_all
      ~OpenTypeKerningClassFlagsParser.read_uint16
      ~OpenTypeKerningClassFlagsParser.read_uint32
      ~OpenTypeKerningClassFlagsParser.read_uint8
      ~OpenTypeKerningClassFlagsParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~OpenTypeKerningClassFlagsParser.encoding
      ~OpenTypeKerningClassFlagsParser.master_count
      ~OpenTypeKerningClassFlagsParser.stream
      ~OpenTypeKerningClassFlagsParser.ttStemsH_count
      ~OpenTypeKerningClassFlagsParser.ttStemsV_count
   
   